IForeventsAPIException class
Base class for API failures.
- Implemented types
- Implementers
Constructors
-
IForeventsAPIException(String message, {int? statusCode, Map<
String, dynamic> ? details}) -
const
Properties
- code → String?
-
The stable machine-readable code (
errorfield) when the API set one.no setter -
details
→ Map<
String, dynamic> ? -
Decoded error body, when the API sent JSON.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- message → String
-
Human-readable description.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- statusCode → int?
-
HTTP status of the failed request, when there was a response.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited